@@ -82,19 +82,19 @@ class Dataset(BaseModel):
     Dataset data.
     """
     dataset_id: str = Field(..., description='The unique dataset uuid.')
-    station_object_key: str = Field(None, description='The object key to the stations data.')
+    # station_object_key: str = Field(None, description='The object key to the stations data.')
     feature: str = Field(..., description='The hydrologic feature associated with the dataset.')
     parameter: str = Field(..., description='The recorded observation parameter.')
     method: str = Field(..., description='The way the recorded observation was obtained.')
-    product_code: str = Field(..., description='The code associated with kind of product produced. This could be generic codes like raw_data or quality_controlled; or it could be more uniquely identifying the simulation product that was produced.')
+    product_code: str = Field(..., description='The code associated with kind of product produced. This could be generic codes like raw_data or quality_controlled_data; or it could be more uniquely identifying the simulation product that was produced.')
     owner: str = Field(..., description='The operator, owner, and/or producer of the associated data.')
     aggregation_statistic: str = Field(..., description='The statistic that defines how the result was calculated. The aggregation statistic is calculated over the time frequency interval associated with the recorded observation.')
-    frequency_interval: str = Field(..., description='The frequency that the observation was recorded at. In the form 1H for hourly.')
-    utc_offset: str = Field(..., description='The offset time from UTC associated with the frequency_interval. For example, if data was collected daily at 9:00, then the frequency_interval would be 24H and the utc_offset would be 9H. The offset must be smaller than the frequency_interval.')
+    frequency_interval: str = Field(..., description='The frequency that the observation was recorded at. In the form 1H for hourly or 24H for daily. A value of T indicates that the data is saved at its instantaneous measured value (usually down to the minute precision).')
+    utc_offset: str = Field(..., description='The offset time from UTC associated with the frequency_interval. For example, if data was collected daily at 9:00 in the timezone of UTC+12, then the frequency_interval would be 24H and the utc_offset would be -3H. This parameter is most important for frequency intervals equal to or greater than 24H and must allign the day with UTC. The offset must be smaller than the frequency_interval.')
     units: str = Field(..., description='The units of the result.')
     license: str = Field(..., description='The legal data license associated with the dataset defined by the owner.')
     attribution: str = Field(..., description='The legally required attribution text to be distributed with the data defined by the owner.')
-    result_type: str = Field(..., description='The collection where the results will be saved.')
+    result_type: str = Field(..., description='The type of result. This is a category to define how the station results can or cannot be handled on the whole. For example, a time_series_grid would indicate that the stations are alligned in a grid.')
     cf_standard_name: str = Field(None, description='The CF conventions standard name for the parameter.')
     wrf_standard_name: str = Field(None, description='The WRF standard name for the parameter.')
     precision: float = Field(None, description='The decimal precision of the result values.')
